'use client';
var jsxRuntime = require('react/jsx-runtime');
var AddIcon = require('@mui/icons-material/Add');
var DeleteOutlinedIcon = require('@mui/icons-material/DeleteOutlined');
var Box = require('@mui/material/Box');
var Stack = require('@mui/material/Stack');
var react = require('react');
require('@mui/material/Button');
require('@mui/material/CircularProgress');
var IconButtonClient = require('./IconButton-client-ih4guhCY.js');
var PreviewModalClient = require('./PreviewModal-client-B37aGgnJ.js');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var AddIcon__default = /*#__PURE__*/_interopDefault(AddIcon);
var DeleteOutlinedIcon__default = /*#__PURE__*/_interopDefault(DeleteOutlinedIcon);
var Box__default = /*#__PURE__*/_interopDefault(Box);
var Stack__default = /*#__PURE__*/_interopDefault(Stack);

/**
 * `ImageField` 上傳圖片，主要是用來包裝上傳圖片的 input，並提供預覽功能。
 */ const ImageField = ({ image: imageOuter, imageName: imageNameOuter, accept = [
    'image/png',
    'image/jpeg',
    'image/jpg'
], onChange, size = 'medium', shape = 'square', disablePreview = false, deletable = true, error, ...rest })=>{
    const [image, setImage] = react.useState(imageOuter);
    react.useEffect(()=>{
        setImage(imageOuter);
    }, [
        imageOuter
    ]);
    const handleChange = (e)=>{
        if (!e.target.files || e.target.files.length === 0) return;
        const file = e.target.files[0];
        if (accept && !accept?.includes(file.type)) return;
        if (onChange) {
            onChange(e, file);
            return;
        }
        setImage(file);
    // onChange?.(e, file);
    };
    const handleDelete = ()=>{
        if (onChange) {
            onChange({}, undefined);
            return;
        }
        setImage(undefined);
    // onChange?.({}, undefined);
    };
    const isPdfFile = react.useMemo(()=>{
        if (!image) return false;
        if (typeof image === 'string') return image.includes('.pdf');
        return image.type === 'application/pdf';
    }, [
        image
    ]);
    const imageUrl = react.useMemo(()=>{
        if (typeof image === 'string') return image;
        if (!image) return undefined;
        return URL.createObjectURL(isPdfFile ? new Blob([
            image
        ], {
            type: 'application/pdf;charset=utf-8'
        }) : image);
    }, [
        image,
        isPdfFile
    ]);
    const imageName = react.useMemo(()=>{
        if (imageNameOuter) return imageNameOuter;
        if (typeof image === 'string') return image.split('/').pop();
        return image?.name;
    }, [
        image,
        imageNameOuter
    ]);
    return /*#__PURE__*/ jsxRuntime.jsx(Box__default.default, {
        ...rest,
        sx: {
            p: image ? 1 : 0,
            border: 2,
            borderStyle: image ? 'solid' : 'dashed',
            borderRadius: shape === 'square' ? 4 : '50%',
            borderColor: error ? 'error.main' : 'divider',
            width: size === 'small' ? 80 : 100,
            height: size === 'small' ? 80 : 100,
            overflow: 'hidden',
            aspectRatio: '1/1',
            position: 'relative',
            backgroundColor: 'background.paper',
            '&:hover': {
                ...!image && {
                    borderColor: 'primary.main'
                },
                '& .action': {
                    opacity: 1
                }
            },
            ...rest?.sx
        },
        children: image ? /*#__PURE__*/ jsxRuntime.jsxs(jsxRuntime.Fragment, {
            children: [
                /*#__PURE__*/ jsxRuntime.jsx(Box__default.default, {
                    component: "div",
                    className: "action",
                    sx: {
                        position: 'absolute',
                        background: 'rgba(0, 0, 0, 0.45)',
                        width: 'calc(100% - 16px)',
                        height: 'calc(100% - 16px)',
                        borderRadius: shape === 'square' ? undefined : '50%',
                        opacity: 0,
                        transition: 'opacity 0.3s ease-in-out'
                    },
                    children: /*#__PURE__*/ jsxRuntime.jsxs(Stack__default.default, {
                        direction: "row",
                        justifyContent: "center",
                        alignItems: "center",
                        height: "100%",
                        children: [
                            !disablePreview && /*#__PURE__*/ jsxRuntime.jsx(PreviewModalClient.PreviewModal, {
                                imageUrl: imageUrl,
                                title: imageName,
                                pdf: isPdfFile
                            }),
                            deletable && /*#__PURE__*/ jsxRuntime.jsx(IconButtonClient.IconButton, {
                                size: "small",
                                sx: {
                                    color: '#fff'
                                },
                                onClick: handleDelete,
                                children: /*#__PURE__*/ jsxRuntime.jsx(DeleteOutlinedIcon__default.default, {})
                            })
                        ]
                    })
                }),
                isPdfFile ? /*#__PURE__*/ jsxRuntime.jsx(Box__default.default, {
                    component: "iframe",
                    src: `${imageUrl}#toolbar=0`,
                    width: "100%",
                    height: "100%",
                    title: imageName,
                    sx: {
                        '*': {
                            msOverflowStyle: 'none',
                            '&::-webkit-scrollbar': {
                                display: 'none'
                            }
                        }
                    }
                }) : /*#__PURE__*/ jsxRuntime.jsx(Box__default.default, {
                    component: "img",
                    src: imageUrl,
                    alt: imageName,
                    sx: {
                        width: '100%',
                        height: '100%',
                        objectFit: 'contain'
                    }
                })
            ]
        }) : /*#__PURE__*/ jsxRuntime.jsxs(Box__default.default, {
            component: "label",
            sx: {
                display: 'flex',
                flexDirection: 'column',
                alignItems: 'center',
                justifyContent: 'center',
                borderRadius: shape === 'square' ? undefined : '50%',
                height: '100%',
                cursor: 'pointer'
            },
            children: [
                /*#__PURE__*/ jsxRuntime.jsx(AddIcon__default.default, {
                    sx: {
                        color: 'divider'
                    }
                }),
                /*#__PURE__*/ jsxRuntime.jsx(Box__default.default, {
                    component: "input",
                    type: "file",
                    onClick: (e)=>{
                        e.target.value = '';
                        e.stopPropagation();
                    },
                    sx: {
                        clip: 'rect(0 0 0 0)',
                        clipPath: 'inset(50%)',
                        height: 1,
                        overflow: 'hidden',
                        position: 'absolute',
                        bottom: 0,
                        left: 0,
                        whiteSpace: 'nowrap',
                        width: 1
                    },
                    onChange: handleChange,
                    accept: accept?.join(',')
                })
            ]
        })
    });
};

exports.ImageField = ImageField;
