'use client';
var jsxRuntime = require('react/jsx-runtime');
var ClearIcon = require('@mui/icons-material/Clear');
var VisibilityIcon = require('@mui/icons-material/Visibility');
var VisibilityOffIcon = require('@mui/icons-material/VisibilityOff');
var material = require('@mui/material');
var react = require('react');

function _interopDefault (e) { return e && e.__esModule ? e : { default: e }; }

var ClearIcon__default = /*#__PURE__*/_interopDefault(ClearIcon);
var VisibilityIcon__default = /*#__PURE__*/_interopDefault(VisibilityIcon);
var VisibilityOffIcon__default = /*#__PURE__*/_interopDefault(VisibilityOffIcon);

const TextFieldInner = ({ value, onChange, defaultValue, InputProps, InputLabelProps, SelectProps, type, allowShowPassword = false, allowClear, selectPlaceholder = 'please select', ...props }, ref)=>{
    const [showPassword, setShowPassword] = react.useState(false);
    const passwordProps = react.useMemo(()=>{
        if (type !== 'password' || !allowShowPassword) return {};
        return {
            type: showPassword ? 'text' : 'password',
            endAdornment: /*#__PURE__*/ jsxRuntime.jsx(material.InputAdornment, {
                position: "end",
                children: /*#__PURE__*/ jsxRuntime.jsx(material.IconButton, {
                    onClick: ()=>setShowPassword((show)=>!show),
                    onMouseDown: (event)=>{
                        event.preventDefault();
                    },
                    "aria-label": "toggle password visibility",
                    children: showPassword ? /*#__PURE__*/ jsxRuntime.jsx(VisibilityOffIcon__default.default, {}) : /*#__PURE__*/ jsxRuntime.jsx(VisibilityIcon__default.default, {})
                })
            })
        };
    }, [
        type,
        allowShowPassword,
        showPassword
    ]);
    const selectProps = react.useMemo(()=>{
        if (!props.select) return {};
        const finalValue = value ?? defaultValue;
        return {
            displayEmpty: true,
            renderValue: finalValue || finalValue === 0 ? undefined : ()=>/*#__PURE__*/ jsxRuntime.jsx(material.Box, {
                    component: "span",
                    color: "text.disabled",
                    children: selectPlaceholder
                }),
            ...allowClear && {
                endAdornment: /*#__PURE__*/ jsxRuntime.jsx(material.IconButton, {
                    className: "MuiClear-icon",
                    onClick: ()=>{
                        onChange?.({
                            target: {
                                value: ''
                            }
                        });
                    },
                    onMouseDown: (event)=>{
                        event.preventDefault();
                    },
                    "aria-label": "clear",
                    sx: {
                        display: 'none',
                        width: '1em',
                        height: '1em',
                        position: 'absolute',
                        right: '7px',
                        top: 'calc(50% - .5em)'
                    },
                    children: /*#__PURE__*/ jsxRuntime.jsx(ClearIcon__default.default, {
                        color: "action",
                        fontSize: "small"
                    })
                })
            }
        };
    }, [
        value,
        defaultValue,
        props.select,
        selectPlaceholder,
        allowClear,
        onChange
    ]);
    return /*#__PURE__*/ jsxRuntime.jsx(material.TextField, {
        ref: ref,
        type: type,
        value: value,
        onChange: onChange,
        defaultValue: defaultValue,
        InputProps: {
            ...InputProps,
            ...passwordProps,
            sx: {
                '&:hover :is(fieldset)': {
                    borderColor: (theme)=>`${theme.palette.primary.dark} !important`
                },
                '& input[type=number]': {
                    MozAppearance: 'textfield'
                },
                '& input::-webkit-outer-spin-button, & input::-webkit-inner-spin-button': {
                    WebkitAppearance: 'none',
                    m: 0
                },
                ...InputProps?.sx
            }
        },
        InputLabelProps: {
            shrink: true,
            ...InputLabelProps,
            sx: {
                '.MuiFormLabel-asterisk': {
                    color: 'error.main'
                },
                ...InputLabelProps?.sx
            }
        },
        SelectProps: {
            ...SelectProps,
            sx: {
                '&:hover': {
                    '.MuiSelect-icon': {
                        display: 'none'
                    },
                    '.MuiClear-icon': {
                        display: 'inline-flex'
                    }
                }
            },
            ...selectProps
        },
        ...props
    });
};
/**
 * `TextField` 元件代表一個文字輸入框，也可以用於選擇框，用於須將label呈現在輸入框border上的情況。
 *
 * 參考 [Material-UI Text Field](https://mui.com/material-ui/react-text-field/)
 */ const TextField = /*#__PURE__*/ react.forwardRef(TextFieldInner);

exports.TextField = TextField;
