'use client';
import { jsxs, jsx, Fragment } from 'react/jsx-runtime';
import CloseIcon from '@mui/icons-material/Close';
import { Dialog, DialogTitle, DialogContent, Stack, Skeleton, DialogActions } from '@mui/material';
import { forwardRef, useState } from 'react';
import { B as Button } from './Button-client-Diz1vWgB.js';
import { I as IconButton } from './IconButton-client-RgaMe93C.js';
import { D as DecorativeTitle } from './DecorativeTitle-client-C6z9r8tV.js';

/**
 * `Modal` 是一個封裝好的對話框元件，提供了標題、內容、確定、取消等功能。
 *
 * 參考 [Material-UI Dialog](https://mui.com/material-ui/react-dialog/)
 */ const Modal = /*#__PURE__*/ forwardRef(({ title, loading = false, loadingOptions = {
    count: 3,
    height: 40
}, showCloseIcon = true, titleProps = {}, disableBackdropClick = false, contentProps = {}, actionsProps = {}, onClose: onCloseOuter, onSubmit, submitButtonText = 'Submit', cancelButtonText = 'Cancel', customActions, children, ...rest }, ref)=>{
    const [isSubmitting, setIsSubmitting] = useState(false);
    const handleCloseInter = (event, reason)=>{
        if (reason === 'backdropClick' && disableBackdropClick || isSubmitting) {
            return;
        }
        onCloseOuter?.(event, reason);
    };
    const handleCloseButtonClick = (event)=>{
        if (!isSubmitting) {
            onCloseOuter?.(event, 'closeButtonClick');
        }
    };
    const handleSubmit = async ()=>{
        setIsSubmitting(true);
        try {
            await onSubmit?.();
        } finally{
            setIsSubmitting(false);
        }
    };
    return /*#__PURE__*/ jsxs(Dialog, {
        ref: ref,
        ...rest,
        onClose: handleCloseInter,
        PaperProps: {
            ...rest?.PaperProps,
            sx: {
                borderRadius: 4,
                ...rest?.PaperProps?.sx
            }
        },
        children: [
            (title || showCloseIcon) && /*#__PURE__*/ jsxs(DialogTitle, {
                color: "primary.main",
                ...titleProps,
                sx: {
                    display: 'flex',
                    justifyContent: 'space-between',
                    alignItems: 'center',
                    ...titleProps?.sx
                },
                children: [
                    /*#__PURE__*/ jsx(DecorativeTitle, {
                        sx: {
                            flex: 1
                        },
                        loading: loading,
                        children: title
                    }),
                    showCloseIcon && /*#__PURE__*/ jsx(IconButton, {
                        "aria-label": "modal-close",
                        onClick: handleCloseButtonClick,
                        disabled: isSubmitting,
                        sx: {
                            color: 'text.secondary'
                        },
                        size: "small",
                        children: /*#__PURE__*/ jsx(CloseIcon, {})
                    })
                ]
            }),
            /*#__PURE__*/ jsx(DialogContent, {
                ...contentProps,
                dividers: contentProps?.dividers ?? true,
                children: loading ? /*#__PURE__*/ jsx(Stack, {
                    spacing: 2,
                    children: Array(loadingOptions.count).fill(null).map((_, i)=>i).map((key)=>/*#__PURE__*/ jsx(Skeleton, {
                            variant: "rounded",
                            height: loadingOptions.height
                        }, key))
                }) : children
            }),
            (onSubmit || customActions) && /*#__PURE__*/ jsx(DialogActions, {
                ...actionsProps,
                sx: {
                    paddingX: 3,
                    paddingY: 2,
                    ...actionsProps?.sx
                },
                children: customActions || /*#__PURE__*/ jsxs(Fragment, {
                    children: [
                        /*#__PURE__*/ jsx(Button, {
                            variant: "outlined",
                            size: "medium",
                            onClick: handleCloseButtonClick,
                            loading: loading,
                            disabled: isSubmitting,
                            sx: {
                                minWidth: 80
                            },
                            children: cancelButtonText
                        }),
                        /*#__PURE__*/ jsx(Button, {
                            variant: "contained",
                            size: "medium",
                            onClick: handleSubmit,
                            loading: loading || isSubmitting,
                            sx: {
                                minWidth: 80
                            },
                            children: submitButtonText
                        })
                    ]
                })
            })
        ]
    });
});
if (process.env.NODE_ENV !== 'production') {
    Modal.displayName = 'GwModal';
}

export { Modal as M };
