'use client';
import './BreadCrumb-client-CyBp43-o.js';
import { jsxs, jsx } from 'react/jsx-runtime';
import { FormControl, Stack, FormLabel, Tooltip, Typography, Box, FormHelperText } from '@mui/material';
import { forwardRef } from 'react';
import '@mui/material/Skeleton';
import '@mui/material/Typography';
import './Dot-client-0SdSGpBH.js';
import './Drawer-client-DjEIXwDW.js';
import HelpOutlineOutlinedIcon from '@mui/icons-material/HelpOutlineOutlined';
import '@mui/material/Stack';
import '@mui/icons-material/Add';
import '@mui/icons-material/DeleteOutlined';
import '@mui/material/Box';
import '@mui/material/Button';
import CircularProgress from '@mui/material/CircularProgress';
import '@mui/material/IconButton';
import '@mui/icons-material/Close';
import '@mui/icons-material/VisibilityOutlined';
import Backdrop from '@mui/material/Backdrop';
import './Modal-client-DBPlSKbp.js';
import '@mui/icons-material/Cancel';
import '@mui/icons-material/CheckCircle';
import '@mui/icons-material/Info';
import '@mui/icons-material/Warning';
import './Switch-client-m3wWmWV7.js';
import './Table-client-C1_NbTsu.js';
import 'react-number-format';
import '@mui/icons-material/Clear';
import '@mui/icons-material/Visibility';
import '@mui/icons-material/VisibilityOff';
import '@mui/material/Alert';
import '@mui/material/Snackbar';

/**
 * `FormItem` 讓我們可以將 form input 所需要的共同前後文特性獨立出來管理，
 * 使被 control 的子元件之間的樣式能夠保持一致性。
 * 例如在 form input 元件 `TextField`, `Switch`, `Checkbox` 當中，
 * 將 `label`, `required`, `error` ...等邏輯與樣式獨立出來藉由 FormItem 來管理。
 *
 * 參考 [Material-UI: FormControl](https://mui.com/material-ui/api/form-control/)
 */ const FormItem = ({ children, label, helperText, helpInfo, maxLength, currentLength, error, fullWidth = true, ...rest })=>/*#__PURE__*/ jsxs(FormControl, {
        fullWidth: fullWidth,
        error: error,
        ...rest,
        children: [
            /*#__PURE__*/ jsxs(Stack, {
                direction: "row",
                justifyContent: "space-between",
                children: [
                    /*#__PURE__*/ jsxs(Stack, {
                        direction: "row",
                        alignItems: "center",
                        justifyContent: "center",
                        spacing: 0.5,
                        sx: {
                            position: 'relative',
                            width: 'fit-content'
                        },
                        children: [
                            /*#__PURE__*/ jsx(FormLabel, {
                                sx: {
                                    fontSize: '0.8rem',
                                    py: 0.5,
                                    '& .MuiFormLabel-asterisk': {
                                        color: 'error.main'
                                    }
                                },
                                children: label
                            }),
                            helpInfo && /*#__PURE__*/ jsx(Tooltip, {
                                title: helpInfo,
                                placement: "top",
                                enterTouchDelay: 50,
                                children: /*#__PURE__*/ jsx(HelpOutlineOutlinedIcon, {
                                    color: "info",
                                    fontSize: "small"
                                })
                            })
                        ]
                    }),
                    maxLength !== undefined && /*#__PURE__*/ jsx(Typography, {
                        component: "span",
                        sx: {
                            fontSize: '0.8rem'
                        },
                        color: error ? 'error' : 'text.secondary',
                        children: `${currentLength ?? 0}/${maxLength}`
                    })
                ]
            }),
            /*#__PURE__*/ jsx(Box, {
                sx: {
                    minHeight: 40,
                    display: 'flex',
                    alignItems: 'flex-start'
                },
                children: children
            }),
            /*#__PURE__*/ jsx(FormHelperText, {
                children: helperText
            })
        ]
    });

/**
 * `LoadingFullScreen` 全螢幕讀取中，通常用於非同步操作時提示使用者等待。
 *
 * 參考 [Material-UI Backdrop](https://mui.com/material-ui/react-backdrop/)
 */ function LoadingFullScreen({ sx, children = /*#__PURE__*/ jsx(CircularProgress, {}), ...rest }) {
    return /*#__PURE__*/ jsx(Backdrop, {
        sx: {
            zIndex: (theme)=>theme.zIndex.drawer + 1000,
            ...sx
        },
        ...rest,
        children: children
    });
}

const getCount = (count)=>{
    if (count < 3) {
        return 3;
    }
    if (count > 5) {
        return 5;
    }
    return count;
};
const bounceAnimation = (frequency, delay)=>({
        animation: `bounce-loading ${frequency}s ${delay * 0.07}s infinite ease-in-out`,
        animationFillMode: 'both',
        '@keyframes bounce-loading': {
            '33%': {
                transform: 'translateY(10px)'
            },
            '66%': {
                transform: 'translateY(-10px)'
            },
            '100%': {
                transform: 'translateY(0)'
            }
        }
    });
const pulseAnimation = (frequency, delay)=>({
        animation: `pulse-loading ${frequency}s ${delay * 0.12 / 1}s infinite cubic-bezier(0.2, 0.68, 0.18, 1.08)`,
        animationFillMode: 'both',
        '@keyframes pulse-loading': {
            '0%': {
                transform: 'scale(1)',
                opacity: 1
            },
            '50%': {
                transform: 'scale(0.1)',
                opacity: 0.7
            },
            '80%': {
                transform: 'scale(1)',
                opacity: 1
            }
        }
    });
const beatAnimation = (frequency, delay)=>({
        animation: `beat-loading ${frequency}s ${delay % 2 ? 0 : `${0.35 / 1}`}s infinite linear`,
        animationFillMode: 'both',
        '@keyframes beat-loading': {
            '50%': {
                transform: 'scale(0.75)',
                opacity: 0.2
            },
            '100%': {
                transform: 'scale(1)',
                opacity: 1
            }
        }
    });
/**
 * `LoadingIndicator` 是一個用來顯示載入中的元件。
 */ const LoadingIndicator = /*#__PURE__*/ forwardRef(({ type = 'bounce', frequency = 0.75, count = 3 }, ref)=>/*#__PURE__*/ jsx(Box, {
        ref: ref,
        display: "flex",
        alignItems: "center",
        justifyContent: "center",
        children: Array.from({
            length: getCount(count)
        }).map((_, index)=>/*#__PURE__*/ jsx(Box, {
                sx: {
                    margin: '2px',
                    width: '12px',
                    height: '12px',
                    bgcolor: 'primary.main',
                    borderRadius: '50%',
                    ...type === 'bounce' && bounceAnimation(frequency, index),
                    ...type === 'pulse' && pulseAnimation(frequency, index),
                    ...type === 'beat' && beatAnimation(frequency, index)
                }
            }, index))
    }));
if (process.env.NODE_ENV !== 'production') {
    LoadingIndicator.displayName = 'GwLoadingIndicator';
}

export { FormItem as F, LoadingFullScreen as L, LoadingIndicator as a };
